@@ -3,7 +3,7 @@
 # See the LICENSE file in the project root for more information
 
 package Search::Elasticsearch::Client::7_0::Direct;
-$Search::Elasticsearch::Client::7_0::Direct::VERSION = '7.714';
+$Search::Elasticsearch::Client::7_0::Direct::VERSION = '8.00';
 use Moo;
 with 'Search::Elasticsearch::Client::7_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -22,14 +22,11 @@ has 'dangling_indices'     => ( is => 'lazy', init_arg => undef );
 has 'data_frame_transform_deprecated' => ( is => 'lazy', init_arg => undef );
 has 'enrich'               => ( is => 'lazy', init_arg => undef );
 has 'eql'                  => ( is => 'lazy', init_arg => undef );
-has 'features'             => ( is => 'lazy', init_arg => undef );
-has 'fleet'                => ( is => 'lazy', init_arg => undef );
 has 'graph'                => ( is => 'lazy', init_arg => undef );
 has 'ilm'                  => ( is => 'lazy', init_arg => undef );
 has 'indices'              => ( is => 'lazy', init_arg => undef );
 has 'ingest'               => ( is => 'lazy', init_arg => undef );
 has 'license'              => ( is => 'lazy', init_arg => undef );
-has 'logstash'             => ( is => 'lazy', init_arg => undef );
 has 'migration'            => ( is => 'lazy', init_arg => undef );
 has 'ml'                   => ( is => 'lazy', init_arg => undef );
 has 'monitoring'           => ( is => 'lazy', init_arg => undef );
@@ -37,13 +34,11 @@ has 'nodes'                => ( is => 'lazy', init_arg => undef );
 has 'rollup'               => ( is => 'lazy', init_arg => undef );
 has 'searchable_snapshots' => ( is => 'lazy', init_arg => undef );
 has 'security'             => ( is => 'lazy', init_arg => undef );
-has 'shutdown'             => ( is => 'lazy', init_arg => undef );
 has 'snapshot'             => ( is => 'lazy', init_arg => undef );
 has 'slm'                  => ( is => 'lazy', init_arg => undef );
 has 'sql'                  => ( is => 'lazy', init_arg => undef );
 has 'ssl'                  => ( is => 'lazy', init_arg => undef );
 has 'tasks'                => ( is => 'lazy', init_arg => undef );
-has 'text_structure'       => ( is => 'lazy', init_arg => undef );
 has 'transform'            => ( is => 'lazy', init_arg => undef );
 has 'watcher'              => ( is => 'lazy', init_arg => undef );
 has 'xpack'                => ( is => 'lazy', init_arg => undef );
@@ -96,14 +91,11 @@ sub _build_dangling_indices     { shift->_build_namespace('DanglingIndices') }
 sub _build_data_frame_transform_deprecated { shift->_build_namespace('DataFrameTransformDeprecated') }
 sub _build_enrich               { shift->_build_namespace('Enrich') }
 sub _build_eql                  { shift->_build_namespace('Eql') }
-sub _build_features             { shift->_build_namespace('Features') }
-sub _build_fleet                { shift->_build_namespace('Fleet') }
 sub _build_graph                { shift->_build_namespace('Graph') }
 sub _build_ilm                  { shift->_build_namespace('ILM') }
 sub _build_indices              { shift->_build_namespace('Indices') }
 sub _build_ingest               { shift->_build_namespace('Ingest') }
 sub _build_license              { shift->_build_namespace('License') }
-sub _build_logstash             { shift->_build_namespace('Logstash') }
 sub _build_migration            { shift->_build_namespace('Migration') }
 sub _build_ml                   { shift->_build_namespace('ML') }
 sub _build_monitoring           { shift->_build_namespace('Monitoring') }
@@ -111,13 +103,11 @@ sub _build_nodes                { shift->_build_namespace('Nodes') }
 sub _build_rollup               { shift->_build_namespace('Rollup') }
 sub _build_searchable_snapshots { shift->_build_namespace('SearchableSnapshots') }
 sub _build_security             { shift->_build_namespace('Security') }
-sub _build_shutdown             { shift->_build_namespace('Shutdown') }
 sub _build_snapshot             { shift->_build_namespace('Snapshot') }
 sub _build_slm                  { shift->_build_namespace('Slm') }
 sub _build_sql                  { shift->_build_namespace('SQL') }
 sub _build_ssl                  { shift->_build_namespace('SSL') }
 sub _build_tasks                { shift->_build_namespace('Tasks') }
-sub _build_text_structure       { shift->_build_namespace('TextStructure') }
 sub _build_transform            { shift->_build_namespace('Transform') }
 sub _build_watcher              { shift->_build_namespace('Watcher') }
 sub _build_xpack                { shift->_build_namespace('XPack') }
@@ -137,7 +127,7 @@ Search::Elasticsearch::Client::7_0::Direct - Thin client with full support for E
 
 =head1 VERSION
 
-version 7.714
+version 8.00
 
 =head1 SYNOPSIS
 
@@ -1689,7 +1679,7 @@ Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Elasticsearch BV.
+This software is Copyright (c) 2022 by Elasticsearch BV.
 
 This is free software, licensed under:
 
